@@ -8,7 +8,7 @@ use PONAPI::Builder::Document;
 
 has repository => (
     is       => 'ro',
-    does     => 'PONAPI::DAO::Repository',
+    does     => 'PONAPI::Repository',
     required => 1,
 );
 
@@ -175,7 +175,7 @@ PONAPI::DAO::Request - DAO request class
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 AUTHORS
 
