@@ -6,16 +6,11 @@ use Moose;
 extends 'PONAPI::DAO::Request';
 
 with 'PONAPI::DAO::Request::Role::UpdateLike',
+     'PONAPI::DAO::Request::Role::HasDataBulk',
      'PONAPI::DAO::Request::Role::HasDataMethods',
      'PONAPI::DAO::Request::Role::HasID',
      'PONAPI::DAO::Request::Role::HasRelationshipType';
 
-has data => (
-    is        => 'ro',
-    isa       => 'ArrayRef[HashRef]',
-    predicate => 'has_data',
-);
-
 sub check_data_type_match { 1 } # to avoid code duplications in HasDataMethods
 
 sub execute {
@@ -59,7 +54,7 @@ PONAPI::DAO::Request::DeleteRelationships - DAO request - delete relationships
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 AUTHORS
 
