@@ -3,8 +3,8 @@ package PONAPI::DAO::Request::Role::UpdateLike;
 
 use Moose::Role;
 
-use PONAPI::DAO::Constants;
-use PONAPI::DAO::Exception;
+use PONAPI::Constants;
+use PONAPI::Exception;
 
 has respond_to_updates_with_200 => (
     is  => 'ro',
@@ -24,7 +24,7 @@ has update_nothing_status => (
 sub _verify_update_response {
     my ( $self, $ret, @extra ) = @_;
 
-    PONAPI::DAO::Exception->throw(
+    PONAPI::Exception->throw(
         internal => 1,
         message  => "update-like operation returned an unexpected value"
     ) unless exists $PONAPI_UPDATE_RETURN_VALUES{$ret};
@@ -76,7 +76,7 @@ sub _get_resource_for_meta {
     return $link . " => " . $self->json->encode( $self->data );
 }
 
-no PONAPI::DAO::Constants;
+no PONAPI::Constants;
 no Moose::Role; 1;
 
 __END__
@@ -91,7 +91,7 @@ PONAPI::DAO::Request::Role::UpdateLike - DAO request role - `update` & like rela
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 AUTHORS
 
