@@ -6,7 +6,7 @@ use Moose;
 extends 'PONAPI::DAO::Request';
 
 with 'PONAPI::DAO::Request::Role::UpdateLike',
-     'PONAPI::DAO::Request::Role::HasDataAttribute',
+     'PONAPI::DAO::Request::Role::HasData',
      'PONAPI::DAO::Request::Role::HasDataMethods',
      'PONAPI::DAO::Request::Role::HasID';
 
@@ -43,7 +43,7 @@ PONAPI::DAO::Request::Update - DAO request - update
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 AUTHORS
 
