@@ -54,7 +54,7 @@ sub BUILDARGS {
     return \%args;
 }
 
-use PONAPI::DAO::Constants;
+use PONAPI::Constants;
 override update_stmt => sub {
     my ($self, %args) = @_;
 
@@ -82,7 +82,7 @@ Test::PONAPI::DAO::Repository::MockDB::Table::Articles - mock repository - table
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 AUTHORS
 
